@@ -5,7 +5,7 @@ Schemata for the JSON serialization of expressions.
 from typing import Optional, Union
 
 from lark import Token, Tree
-from marshmallow import Schema, fields, post_load, pre_dump
+from marshmallow import Schema, fields, post_dump, post_load, pre_dump, pre_load
 
 # in the classes/schemata we don't care about if there aren't enough public versions.
 # We also don't care about unused kwargs, or no self-use.
@@ -21,8 +21,8 @@ class _TokenOrTree:
         self.token = token
         self.tree = tree
 
-    token: Token
-    tree: Tree
+    token: Optional[Token]
+    tree: Optional[Tree]
 
 
 class _TokenOrTreeSchema(Schema):
@@ -108,3 +108,39 @@ class TreeSchema(Schema):
         :return:
         """
         return Tree(**data)
+
+
+def _compress(data: dict) -> dict:
+    """
+    a function that "throws away" unnecessary data.
+    The price we pay is that we loose the ability to easily deserialize the result.
+    But if we're only interested in a simple tree that's fine.
+    """
+    if "children" in data and "type" in data and data["type"].endswith("_composition"):
+        return {data["type"]: [_compress(child) for child in data["children"]]}
+    if "tree" in data and "token" in data and data["token"] is None:
+        return _compress(data["tree"])
+    if "type" in data and data["type"] == "condition_key":
+        return data["children"][0]["token"]["value"]
+    return data
+
+
+class CompactTreeSchema(TreeSchema):
+    """
+    A tree schema that leads to significantly more compact output but can only be used for serialization
+    (not deserialization)
+    """
+
+    @post_dump
+    def serialize(self, data, **kwargs) -> dict:
+        """
+        Serialize as compact tree
+        """
+        return _compress(data)
+
+    @pre_load
+    def deserialize(self, data, **kwargs) -> Tree:
+        """
+        This is out of scope
+        """
+        raise NotImplementedError("Deserializing a compact tree is not supported.")
