@@ -3,7 +3,7 @@
 from unittest.mock import AsyncMock
 
 import inject
-import pytest
+import pytest  # type:ignore[import]
 
 from ahbicht.content_evaluation.rc_evaluators import RcEvaluator
 from ahbicht.evaluation_results import RequirementConstraintEvaluationResult
